==> dynamite-0.1.0.tar.gz: dynamite-0.1.0/dynamite/schema.py <==
class Schema(object):
    _state = None
    _fields = None
    defaults_to_python = False

    def __init__(self, **kwargs):
        self._state = {}
        self._fields = self.get_fields()
        self.init_state()
        for key in kwargs:
            if key in self.fields:
                self.set_state(key, kwargs[key])
        self._range_field = None
        self._hash_field = None
        for field in self.fields:
            if self.fields[field]._range:
                self._range_field = field
            if self.fields[field]._hash:
                self._hash_field = field

    def init_state(self):
        for field in self.fields:
            self.set_state(field, self.fields[field].default)

    def set_state(self, name, value):
        self.fields[name].validate(value)
        self.state[name] = value
        return value

    def get_state(self, name):
        value = self.state[name]
        self.fields[name].validate(value)
        return value

    @classmethod
    def get_fields(cls):
        from dynamite.fields import BaseField
        return {elem: getattr(cls, elem) for elem in dir(cls) if isinstance(getattr(cls, elem), BaseField)}

    @property
    def fields(self):
        return self._fields

    @property
    def state(self):
        return self._state

    def __setattr__(self, key, value):
        if self.fields is not None and key in self.fields:
            self.set_state(key, value)
        else:
            super(Schema, self).__setattr__(key, value)

    def __getattribute__(self, item):
        fields = super(Schema, self).__getattribute__('_fields')
        if fields is not None and item in fields:
            return self.get_state(item)
        return super(Schema, self).__getattribute__(item)

    def to_db(self, data=None):
        if data is None:
            data = self.state
        result = {}
        for field in self.fields:
            result[field] = self.fields[field].to_db(data[field])
        return result

    def to_python(self, data):
        for field in self.fields:
            value = None
            if field in data:
                value = self.fields[field].to_python(data[field])
            elif self.defaults_to_python:
                value = self.fields[field].default
            if value is not None:
                self.set_state(field, value)
        return self

==> dynamite-0.2.0.tar.gz: dynamite-0.2.0/dynamite/schema.py <==
class Schema(object):
    _state = None
    _fields = None
    _range_field = None
    _hash_field = None

    defaults_to_python = False

    def __init__(self, **kwargs):
        self._state = {}
        if self.__class__._fields is None:
            self.get_fields()
        self.init_state()
        for key in kwargs:
            if key in self.fields:
                self.set_state(key, kwargs[key])

    def get_default_value(self, field):
        value = self.fields[field].default
        if callable(value):
            value = value()
        return value


    def init_state(self):
        for field in self.fields:
            value = self.get_default_value(field)
            self.set_state(field, value)

    def set_state(self, name, value):
        self.fields[name].validate(value)
        self.state[name] = value
        return value

    def get_state(self, name):
        value = self.state[name]
        self.fields[name].validate(value)
        return value

    @classmethod
    def get_fields(cls):
        from dynamite.fields import BaseField
        cls._fields = {elem: getattr(cls, elem) for elem in dir(cls) if isinstance(getattr(cls, elem), BaseField)}

        for field in cls._fields:
            if cls._fields[field]._range:
                cls._range_field = field
            if cls._fields[field]._hash:
                cls._hash_field = field

    @property
    def fields(self):
        return self.__class__._fields

    @property
    def state(self):
        return self._state

    def __setattr__(self, key, value):
        if self.fields is not None and key in self.fields:
            self.set_state(key, value)
        else:
            super(Schema, self).__setattr__(key, value)

    def __getattribute__(self, item):
        fields = super(Schema, self).__getattribute__('_fields')
        if fields is not None and item in fields:
            return self.get_state(item)
        return super(Schema, self).__getattribute__(item)

    def to_db(self, data=None):
        if data is None:
            data = self.state
        result = {}
        for field in self.fields:
            result[field] = self.fields[field].to_db(data[field])
        return result

    def to_python(self, data):
        for field in self.fields:
            value = None
            if field in data:
                value = self.fields[field].to_python(data[field])
            elif self.defaults_to_python:
                value = self.get_default_value(field)
            if value is not None:
                self.set_state(field, value)
        return self
